==> haskell-wl-pprint-annotated-0.1.0.1-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.1
id: wl-pprint-annotated-0.1.0.1-15NaI63Tavn9BweNGcXZhU
key: wl-pprint-annotated-0.1.0.1-15NaI63Tavn9BweNGcXZhU
license: BSD-3-Clause
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
author: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.
category: Text
abi: 9b7ff722eca3089030b2e7c13a8b4db9
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.WL
hidden-modules: Paths_wl_pprint_annotated
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-annotated-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wl-pprint-annotated-0.1.0.1
hs-libraries: HSwl-pprint-annotated-0.1.0.1-15NaI63Tavn9BweNGcXZhU
depends:
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.1-29-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.1
id: wl-pprint-annotated-0.1.0.1-8MB2b3NbzeKFk2XIqcxK7P
key: wl-pprint-annotated-0.1.0.1-8MB2b3NbzeKFk2XIqcxK7P
license: BSD-3-Clause
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
author: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.
category: Text
abi: 35c7f90def2c326f154ff16d4cd04dc4
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.WL
hidden-modules: Paths_wl_pprint_annotated
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-annotated-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wl-pprint-annotated-0.1.0.1
hs-libraries: HSwl-pprint-annotated-0.1.0.1-8MB2b3NbzeKFk2XIqcxK7P
depends:
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
